@@ -473,7 +473,7 @@ bool RdpSession::start()
         settings->ProxyPort = proxyHostAddress.port(defaultPort);
     }
 
-    const auto gatewayServerAddress = QUrl(m_preferences->proxyHost());
+    const auto gatewayServerAddress = QUrl(m_preferences->gatewayServer());
     if (!gatewayServerAddress.isEmpty()) {
         settings->GatewayHostname = gatewayServerAddress.host().toLocal8Bit().data();
         settings->GatewayPort = gatewayServerAddress.port(3389);
@@ -615,7 +615,7 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
             } else {
                 flags |= value;
             }
-        } else if (wheelEvent->angleDelta().x() != 0) {
+        } else if (delta.x() != 0) {
             value = std::clamp(std::abs(delta.x()), 0, 0xFF);
             flags |= PTR_FLAGS_HWHEEL;
             if (wheelEvent->angleDelta().x() < 0) {
@@ -624,6 +624,8 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
             } else {
                 flags |= value;
             }
+        } else {
+            break;
         }
 
         auto position = wheelEvent->position();
