@@ -19,6 +19,7 @@
 #define TCP_PORT_RDP 3389
 
 class RdpSession;
+class QMimeData;
 
 class RdpView : public RemoteView
 {
@@ -62,16 +63,10 @@ protected:
     QSize initialSize();
 
     void paintEvent(QPaintEvent *event) override;
-
-    void keyPressEvent(QKeyEvent *event) override;
-    void keyReleaseEvent(QKeyEvent *event) override;
-
-    void mousePressEvent(QMouseEvent *event) override;
-    void mouseReleaseEvent(QMouseEvent *event) override;
-    void mouseDoubleClickEvent(QMouseEvent *event) override;
-    void mouseMoveEvent(QMouseEvent *event) override;
-
-    void wheelEvent(QWheelEvent *event) override;
+    void handleKeyEvent(QKeyEvent *event) override;
+    void handleWheelEvent(QWheelEvent *event) override;
+    void handleMouseEvent(QMouseEvent *event) override;
+    void handleLocalClipboardChanged(const QMimeData *data) override;
 
 private:
     void onRectangleUpdated(const QRect &rect);
